@@ -110,12 +110,12 @@ async fn insert_worst_case_records(num: i64) -> Result<(), anyhow::Error> {
 
 fn generate_group_id(rng: &mut impl Rng) -> String {
     let random_group_id = rng.gen_range(1..=6);
-    format!("group_{}", random_group_id)
+    format!("group_{random_group_id}")
 }
 
 fn generate_site_id(rng: &mut impl Rng) -> String {
     let random_group_id = rng.gen_range(1..=6);
-    format!("site_{}", random_group_id)
+    format!("site_{random_group_id}")
 }
 
 fn generate_component_scores(rng: &mut impl Rng) -> i64 {
@@ -184,7 +184,7 @@ fn benchmark_record_query_from_auditor(c: &mut Criterion) {
     let time_and_site_query = QueryBuilder::new()
         .with_meta_query(MetaQuery::new().meta_operator(
             "site_id".to_string(),
-            MetaOperator::default().contains("site_1".to_string()),
+            MetaOperator::default().contains(vec!["site_1".to_string()]),
         ))
         .with_start_time(
             Operator::default()
@@ -214,7 +214,7 @@ fn benchmark_record_query_from_auditor(c: &mut Criterion) {
         )
         .with_meta_query(MetaQuery::new().meta_operator(
             "site_id".to_string(),
-            MetaOperator::default().contains("site_1".to_string()),
+            MetaOperator::default().contains(vec!["site_1".to_string()]),
         ))
         .with_component_query(
             ComponentQuery::new()
@@ -235,7 +235,7 @@ fn benchmark_record_query_from_auditor(c: &mut Criterion) {
         )
         .with_meta_query(MetaQuery::new().meta_operator(
             "group_id".to_string(),
-            MetaOperator::default().contains("group_1".to_string()),
+            MetaOperator::default().contains(vec!["group_1".to_string()]),
         ))
         .with_component_query(
             ComponentQuery::new()
