@@ -11,6 +11,7 @@ use secrecy::{ExposeSecret, Secret};
 use serde_aux::field_attributes::deserialize_number_from_string;
 use sqlx::ConnectOptions;
 use sqlx::postgres::{PgConnectOptions, PgSslMode};
+use std::collections::HashMap;
 use tracing_subscriber::filter::LevelFilter;
 
 #[derive(serde::Deserialize, Debug)]
@@ -26,9 +27,111 @@ pub struct Settings {
     #[serde(deserialize_with = "deserialize_log_level")]
     pub log_level: LevelFilter,
     pub tls_config: Option<TLSConfig>,
+    pub rbac_config: Option<RbacConfig>,
+    #[serde(default = "default_ignore_record_exists_error")]
+    pub ignore_record_exists_error: bool,
+    pub archival_config: Option<ArchivalConfig>,
 }
 
-// Set the default values for TLSConfig options
+#[derive(Debug, Clone, serde::Deserialize)]
+pub enum CompressionType {
+    Gzip,
+    Snappy,
+}
+
+#[derive(Debug, Clone, serde::Deserialize)]
+pub struct ArchivalConfig {
+    pub archive_older_than_months: i32,
+    pub archive_path: String,
+    #[serde(default = "default_archive_file_prefix")]
+    pub archive_file_prefix: String,
+    pub cron_schedule: String, // e.g., "0 0 2 1 * *" // Monthly
+    #[serde(default = "default_compression_type")]
+    pub compression_type: CompressionType,
+}
+
+fn default_compression_type() -> CompressionType {
+    CompressionType::Gzip
+}
+
+fn default_archive_file_prefix() -> String {
+    "auditor".to_string()
+}
+
+#[derive(serde::Deserialize, Debug, Clone)]
+#[serde(deny_unknown_fields)]
+pub struct RbacConfig {
+    #[serde(default = "default_enforce_rbac")]
+    pub enforce_rbac: bool,
+    #[serde(default = "default_base_policies")]
+    pub base_policies: Vec<Vec<String>>,
+    pub monitoring_role_cn: Option<Vec<String>>,
+    pub write_access_cn: Option<Vec<String>>,
+    pub read_access_cn: Option<Vec<String>>,
+    pub data_access_rules: Option<Vec<Cn>>,
+}
+
+fn default_ignore_record_exists_error() -> bool {
+    false
+}
+
+fn default_enforce_rbac() -> bool {
+    false
+}
+
+#[derive(serde::Deserialize, Debug, Clone)]
+#[serde(deny_unknown_fields)]
+pub struct Cn {
+    pub reader_cn: String,
+    pub meta_info: HashMap<String, Vec<String>>,
+}
+
+fn default_base_policies() -> Vec<Vec<String>> {
+    vec![
+        vec![
+            "monitoring_role".to_string(),
+            "/metrics".to_string(),
+            "GET".to_string(),
+        ],
+        vec![
+            "write_access_base".to_string(),
+            "/record".to_string(),
+            "POST".to_string(),
+        ],
+        vec![
+            "write_access_base".to_string(),
+            "/record".to_string(),
+            "PUT".to_string(),
+        ],
+        vec![
+            "write_access_base".to_string(),
+            "/records".to_string(),
+            "POST".to_string(),
+        ],
+        vec![
+            "write_access_base".to_string(),
+            "/healthcheck".to_string(),
+            "GET".to_string(),
+        ],
+        vec![
+            "read_access_base".to_string(),
+            "/records".to_string(),
+            "GET".to_string(),
+        ],
+        vec![
+            "read_access_base".to_string(),
+            "/record/*".to_string(),
+            "GET".to_string(),
+        ],
+        vec![
+            "read_access_base".to_string(),
+            "/healthcheck".to_string(),
+            "GET".to_string(),
+        ],
+    ]
+}
+
+//Set the default values for TLSConfig options
 #[derive(serde::Deserialize, Debug)]
 #[serde(deny_unknown_fields)]
 pub struct TLSConfig {
@@ -125,6 +228,24 @@ pub struct DatabaseMetricsSettings {
     #[serde_as(as = "serde_with::DurationSeconds<i64>")]
     pub frequency: chrono::Duration,
     pub metrics: Vec<crate::metrics::DatabaseMetricsOptions>,
+    #[serde(default = "default_meta_key_site")]
+    pub meta_key_site: String,
+    #[serde(default = "default_meta_key_group")]
+    pub meta_key_group: String,
+    #[serde(default = "default_meta_key_user")]
+    pub meta_key_user: String,
+}
+
+fn default_meta_key_site() -> String {
+    "site".to_string()
+}
+
+fn default_meta_key_group() -> String {
+    "group".to_string()
+}
+
+fn default_meta_key_user() -> String {
+    "user".to_string()
 }
 
 fn default_db_metrics_frequency() -> chrono::Duration {
@@ -136,6 +257,9 @@ fn default_metrics() -> MetricsSettings {
         database: DatabaseMetricsSettings {
             frequency: default_db_metrics_frequency(),
             metrics: vec![],
+            meta_key_site: default_meta_key_site(),
+            meta_key_group: default_meta_key_group(),
+            meta_key_user: default_meta_key_user(),
         },
     }
 }
@@ -205,6 +329,8 @@ pub fn get_configuration() -> Result<Settings, config::ConfigError> {
             .prefix_separator("_")
             .list_separator(",")
             .with_list_parse_key("application.addr")
+            .with_list_parse_key("rbac_config.read_access_cn")
+            .with_list_parse_key("rbac_config.write_access_cn")
             .try_parsing(true),
     );
 
