@@ -1,5 +1,7 @@
+use std::collections::HashMap;
+
 use crate::routes::{Filters, advanced_record_filtering, get_one_record};
-use actix_web::{HttpRequest, HttpResponse, ResponseError, web};
+use actix_web::{HttpMessage, HttpRequest, HttpResponse, ResponseError, web};
 use serde_json::json;
 use sqlx::PgPool;
 use thiserror::Error;
@@ -13,17 +15,27 @@ pub struct RecordQuery {
 pub async fn query_records(
     query: HttpRequest,
     pool: web::Data<PgPool>,
+    enforce_rbac: web::Data<bool>,
 ) -> Result<HttpResponse, GetFilterError> {
     let query_string = query.query_string();
 
-    let filters: Filters = match serde_qs::from_str(query_string) {
+    let mut filters: Filters = match serde_qs::from_str(query_string) {
         Ok(filters) => filters,
         Err(err) => return Err(GetFilterError::InvalidQuery(err.to_string())),
     };
 
-    if query_string.is_empty() {
-        // This case explicitly checks if the query is empty. Then it returns all records.
+    if **enforce_rbac
+        && let Some(meta_info) = query.extensions().get::<HashMap<String, Vec<String>>>()
+    {
+        let meta_info = meta_info.clone();
 
+        match filters.enforce_meta_filtering(meta_info) {
+            Ok(_) => {}
+            Err(msg) => return Err(GetFilterError::UnexpectedError(msg)),
+        }
+    }
+
+    if query_string.is_empty() {
         let stream = advanced_record_filtering(filters, pool.as_ref().clone()).await;
         return Ok(HttpResponse::Ok()
             .content_type("application/json")
